pilas.demos.piezas.Pieza

Package pilas :: Package demos :: Module piezas :: Class Pieza |
[hide private]
[frames] | no frames]

# Class Pieza

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
          actores.actor.Actor --+
                                |
          actores.animado.Animado --+
                                    |
                                   Pieza

Representa una pieza del rompecabezas.

Esta pieza se puede arrastrar con el mouse y cuando se suelta intentará conectarse con las demás.

Instance Methods | [hide private]
__init__(self, escena_padre, grilla, cuadro, filas, columnas) Genera la pieza que representa una parte de la imagen completa. | source code
asignar_numero_de_piezas_laterales(self, cuadro, columnas) Guarda el numero de las piezas que se pueden conectar en sus bordes. | source code
soltar_todas_las_piezas_del_grupo(self) | source code
soltar(self) | source code
se_pueden_conectar_los_bordes(self, borde1, borde2) | source code
intentar_conectarse_a(self, otra) Intenta vincular dos piezas, siempre y cuando coincidan en sus bordes. | source code
conectar_con(self, otra_pieza) | source code
__repr__(self) repr(x) | source code
set_x(self, x) A diferencia de los actores normales, las piezas tienen que mover a todo su grupo. | source code
set_y(self, y) A diferencia de los actores normales, las piezas tienen que mover a todo su grupo. | source code
get_x(self) | source code
get_y(self) | source code
mostrar_arriba_todas_las_piezas(self) | source code
mostrar_abajo_todas_las_piezas(self) | source code
Inherited from `actores.animado.Animado`: `definir_cuadro` Inherited from `actores.actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `actualizar`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `eliminar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_z` Inherited from `actores.actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
| x Define la posición horizontal.
| y Define la posición vertical.
Inherited from `actores.actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, escena_padre, grilla, cuadro, filas, columnas) (Constructor) | source code
Genera la pieza que representa una parte de la imagen completa. Overrides: estudiante.Estudiante.__init__

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### set_x(self, x) | source code
A diferencia de los actores normales, las piezas tienen que mover a todo su grupo. Overrides: actores.actor.Actor.set_x

### set_y(self, y) | source code
A diferencia de los actores normales, las piezas tienen que mover a todo su grupo. Overrides: actores.actor.Actor.set_y

### get_x(self) | source code
Overrides: actores.actor.Actor.get_x

### get_y(self) | source code
Overrides: actores.actor.Actor.get_y

Property Details | [hide private]

### x Define la posición horizontal. Get Method: get_x(self) Set Method: set_x(self, x) - A diferencia de los actores normales, las piezas tienen que mover a todo su grupo.

### y Define la posición vertical. Get Method: get_y(self) Set Method: set_y(self, y) - A diferencia de los actores normales, las piezas tienen que mover a todo su grupo.